==> haskell-lens-aeson-1.0.2-96-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-8Bu2uFj7JX8FDcm4bEXhei
key: lens-aeson-1.0.2-8Bu2uFj7JX8FDcm4bEXhei
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 75433799e3bbc96f88045c20138b8d83
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.4.3/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-8Bu2uFj7JX8FDcm4bEXhei
depends:
    base-4.11.1.0 lens-4.17-IpPiOSaq8WuDwiOH7KFqYw text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ bytestring-0.10.8.2
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             lens-4.17-IpPiOSaq8WuDwiOH7KFqYw=a68928848901fd8f80a6b71d3e478505
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.0.2-97-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7
key: lens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 72f9af39287f161ccbd2c8c7632c9903
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.4.3/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7
depends:
    base-4.11.1.0 lens-4.17-4C4gMEkWPox35sMHxQ6P7t text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE bytestring-0.10.8.2
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             lens-4.17-4C4gMEkWPox35sMHxQ6P7t=4cb9fc45e7308a0ad354f525c2839895
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
